# Finance Report

Finance_Report — Python-пакет для анализа доходов и расходов компании. Загружает данные из CSV-файла, группирует их по категориям и создает отчет с суммами для каждой категории.

## Установка

Установите библиотеку с помощью команды:

```bash
pip install finance_report
```

## Пример использования 

```bash
 finance-report --input-file transactions.csv --output-file repory.txt
```

## Пример исходных данных

```bash
transaction_id,category,amount
1,Доход,10000
2,Расход,2000
3,Доход,5000
4,Расход,1500
5,Доход,7000
6,Расход,3000
7,Доход,2000
8,Расход,1000
9,Доход,4000
10,Расход,2500
```